==> sign-center-api-0.0.2.2-20180428.084506-6-sources.jar: cn/com/duiba/sign/center/api/dto/AppSignOperatingPositionDto.java <==
package cn.com.duiba.sign.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2017/12/5.
 */
public class AppSignOperatingPositionDto implements Serializable{
    private static final long serialVersionUID = 8012378687604934242L;
    /**
     * 自增ID
     **/
    private Long id;
    /**
     * 归属的AppId
     **/
    private Long appId;
    /**
     * 签到活动ID
     */
    private Long signActId;
    /**
     * 运营位模板ID，即tb_sign_operating_position表中的数据ID
     **/
    private Long modelId;
    /**
     * 标题文案
     **/
    private String title;
    /**
     * 跳转链接
     **/
    private String targetUrl;
    /**
     * 展示图片
     **/
    private String image;
    /**
     * 是否在页面展示
     */
    private Boolean openShow;
    /**
     * 创建时间
     **/
    private Date gmtCreate;
    /**
     * 修改时间
     **/
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSignActId() {
        return signActId;
    }

    public void setSignActId(Long signActId) {
        this.signActId = signActId;
    }

    public Long getModelId() {
        return modelId;
    }

    public void setModelId(Long modelId) {
        this.modelId = modelId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTargetUrl() {
        return targetUrl;
    }

    public void setTargetUrl(String targetUrl) {
        this.targetUrl = targetUrl;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public Boolean getOpenShow() {
        return openShow;
    }

    public void setOpenShow(Boolean openShow) {
        this.openShow = openShow;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> sign-center-api-0.3.31-sources.jar: cn/com/duiba/sign/center/api/dto/AppSignOperatingPositionDto.java <==
package cn.com.duiba.sign.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2017/12/5.
 */
public class AppSignOperatingPositionDto implements Serializable{
    private static final long serialVersionUID = 8012378687604934242L;
    /**
     * 自增ID
     **/
    private Long id;
    /**
     * 归属的AppId
     **/
    private Long appId;
    /**
     * 签到活动ID
     */
    private Long signActId;
    /**
     * 运营位模板ID，即tb_sign_operating_position表中的数据ID
     **/
    private Long modelId;
    /**
     * 标题文案
     **/
    private String title;
    /**
     * 跳转链接
     **/
    private String targetUrl;
    /**
     * 展示图片
     **/
    private String image;
    /**
     * 是否在页面展示
     */
    private Boolean openShow;
    /**
     * 内容简介
     */
    private String content;
    /**
     * 创建时间
     **/
    private Date gmtCreate;
    /**
     * 修改时间
     **/
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSignActId() {
        return signActId;
    }

    public void setSignActId(Long signActId) {
        this.signActId = signActId;
    }

    public Long getModelId() {
        return modelId;
    }

    public void setModelId(Long modelId) {
        this.modelId = modelId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTargetUrl() {
        return targetUrl;
    }

    public void setTargetUrl(String targetUrl) {
        this.targetUrl = targetUrl;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public Boolean getOpenShow() {
        return openShow;
    }

    public void setOpenShow(Boolean openShow) {
        this.openShow = openShow;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    @Override
    public String toString() {
        return "AppSignOperatingPositionDto{" +
                "id=" + id +
                ", appId=" + appId +
                ", signActId=" + signActId +
                ", modelId=" + modelId +
                ", title='" + title + '\'' +
                ", targetUrl='" + targetUrl + '\'' +
                ", image='" + image + '\'' +
                ", openShow=" + openShow +
                ", content='" + content + '\'' +
                ", gmtCreate=" + gmtCreate +
                ", gmtModified=" + gmtModified +
                '}';
    }
}
